@@ -1,7 +1,7 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Feed/trunk/lib/Data/Feed/Web/Entry.pm 66819 2008-07-24T12:49:10.752170Z 33rpm  $
+# $Id: /mirror/coderepos/lang/perl/Data-Feed/trunk/lib/Data/Feed/Web/Entry.pm 102544 2009-03-19T08:58:09.853141Z daisuke  $
 
 package Data::Feed::Web::Entry;
-use Moose::Role;
+use Any::Moose '::Role';
 use Data::Feed::Web::Enclosure;
 
 with 'Data::Feed::Item';
@@ -23,7 +23,7 @@ requires 'issued';
 requires 'modified';
 requires 'enclosures';
 
-no Moose;
+no Any::Moose '::Role';
 
 1;
 
