@@ -1,7 +1,7 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Feed/trunk/lib/Data/Feed/Web/Feed.pm 88595 2008-10-20T16:13:11.386706Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Feed/trunk/lib/Data/Feed/Web/Feed.pm 102544 2009-03-19T08:58:09.853141Z daisuke  $
 
 package Data::Feed::Web::Feed;
-use Moose::Role;
+use Any::Moose '::Role';
 
 has 'feed' => (
     is => 'rw',
@@ -22,7 +22,7 @@ requires qw(
     title
 );
 
-no Moose;
+no Any::Moose '::Role';
 
 1;
 
